@@ -1,5 +1,7 @@
+import hashlib
 import random
 import traceback
+from io import BytesIO
 from itertools import chain
 from typing import Any, Dict, List, NoReturn, Type, Union
 
@@ -12,7 +14,7 @@ from meme_generator.exception import (
 )
 from meme_generator.meme import Meme, MemeParamsType
 from meme_generator.utils import TextProperties, render_meme_list
-from nonebot import on_command, on_message
+from nonebot import on_command, on_message, require
 from nonebot.adapters.onebot.v11 import Bot as V11Bot
 from nonebot.adapters.onebot.v11 import GroupMessageEvent as V11GMEvent
 from nonebot.adapters.onebot.v11 import Message as V11Msg
@@ -40,7 +42,12 @@ from nonebot.typing import T_Handler, T_State
 from nonebot.utils import run_sync
 from pypinyin import Style, pinyin
 
+require("nonebot_plugin_localstore")
+
+from nonebot_plugin_localstore import get_cache_dir
+
 from .config import memes_config
+from .data_source import ImageSource, User, UserInfo
 from .depends import (
     IMAGE_SOURCES_KEY,
     TEXTS_KEY,
@@ -48,16 +55,10 @@ from .depends import (
     split_msg_v11,
     split_msg_v12,
 )
+from .exception import NetworkError, PlatformUnsupportError
 from .manager import ActionResult, MemeMode, meme_manager
 from .rule import command_rule, regex_rule
-from .utils import (
-    ImageSource,
-    NetworkError,
-    PlatformUnsupportError,
-    User,
-    UserInfo,
-    meme_info,
-)
+from .utils import meme_info
 
 __plugin_meta__ = PluginMetadata(
     name="表情包制作",
@@ -66,10 +67,12 @@ __plugin_meta__ = PluginMetadata(
     extra={
         "unique_name": "memes",
         "author": "meetwq <meetwq@gmail.com>",
-        "version": "0.4.2",
+        "version": "0.4.5",
     },
 )
 
+memes_cache_dir = get_cache_dir("nonebot_plugin_memes")
+
 
 PERM_EDIT = GROUP_ADMIN | GROUP_OWNER | PRIVATE_FRIEND | PRIVATE | SUPERUSER
 PERM_GLOBAL = SUPERUSER
@@ -119,7 +122,20 @@ async def _(bot: Union[V11Bot, V12Bot], matcher: Matcher, user_id: str = get_use
         )
         for meme in memes
     ]
-    img = await run_sync(render_meme_list)(meme_list)
+
+    # cache rendered meme list
+    meme_list_hashable = [
+        ({"key": meme.key, "keywords": meme.keywords}, prop) for meme, prop in meme_list
+    ]
+    meme_list_hash = hashlib.md5(str(meme_list_hashable).encode("utf8")).hexdigest()
+    meme_list_cache_file = memes_cache_dir / f"{meme_list_hash}.jpg"
+    if not meme_list_cache_file.exists():
+        img = await run_sync(render_meme_list)(meme_list)
+        with open(meme_list_cache_file, "wb") as f:
+            f.write(img.getvalue())
+    else:
+        img = BytesIO(meme_list_cache_file.read_bytes())
+
     msg = "触发方式：“关键词 + 图片/文字”\n发送 “表情详情 + 关键词” 查看表情参数和预览\n目前支持的表情列表："
 
     if isinstance(bot, V11Bot):
@@ -356,18 +372,12 @@ def create_matchers():
     for meme in meme_manager.memes:
         matchers: List[Type[Matcher]] = []
         if meme.keywords:
-            # 纯文字输入的表情，在命令后加空格以防止误触发
-            keywords = (
-                [keyword.rstrip() + " " for keyword in meme.keywords]
-                if meme.params_type.min_images == 0 and meme.params_type.max_images == 0
-                else meme.keywords
-            )
             matchers.append(
-                on_message(command_rule(keywords), block=False, priority=12)
+                on_message(command_rule(meme.keywords), block=False, priority=12)
             )
         if meme.patterns:
             matchers.append(
-                on_message(regex_rule(meme.patterns), block=False, priority=12)
+                on_message(regex_rule(meme.patterns), block=False, priority=13)
             )
 
         for matcher in matchers:
