@@ -4,14 +4,11 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 import yaml
-from nonebot import require
-from nonebot.log import logger
-from pydantic import BaseModel
-
-require("nonebot_plugin_localstore")
 from meme_generator.manager import get_memes
 from meme_generator.meme import Meme
+from nonebot.log import logger
 from nonebot_plugin_localstore import get_config_file
+from pydantic import BaseModel
 
 from .config import memes_config
 
